ipsolve_

Function ipsolve_ 

#[unsafe(no_mangle)]
pub unsafe extern "C" fn ipsolve_( fproblem: *mut *mut c_void, x: *mut Number, g: *mut Number, obj_val: *mut Number, mult_g: *mut Number, mult_x_l: *mut Number, mult_x_u: *mut Number, idat: *mut Index, ddat: *mut Number, ) -> Index
ipsolve_(FProblem, X, G, OBJ_VAL, MULT_G, MULT_X_L, MULT_X_U, IDAT, DDAT) -> Index.

Safety

All pointer arguments must satisfy the contracts documented on crate::IpoptSolve. idat/ddat are scratch arrays passed back to the user’s Fortran callbacks.