CreateIpoptProblem

Function CreateIpoptProblem 

#[unsafe(no_mangle)]
pub unsafe extern "C" fn CreateIpoptProblem( n: Index, x_L: *const Number, x_U: *const Number, m: Index, g_L: *const Number, g_U: *const Number, nele_jac: Index, nele_hess: Index, index_style: Index, eval_f: Option<Eval_F_CB>, eval_g: Option<Eval_G_CB>, eval_grad_f: Option<Eval_Grad_F_CB>, eval_jac_g: Option<Eval_Jac_G_CB>, eval_h: Option<Eval_H_CB>, ) -> IpoptProblem
Port of IpStdCInterface.cpp:CreateIpoptProblem. Returns NULL on invalid arguments (negative n/m, missing required callbacks, NULL bound pointers when the corresponding dimension is positive).

Safety

x_L, x_U must be valid pointers to n Numbers when n > 0. g_L, g_U must be valid pointers to m Numbers when m > 0. The callback function pointers must be valid for the lifetime of the returned IpoptProblem.